AFConfigurationItemOptionChoice class

Superclass for configuration definitions that offer a list of string values, for example 'debug', 'production', 'test'

Inheritance
Implementers

Constructors

AFConfigurationItemOptionChoice({required AFLibraryID libraryId, required String name, required dynamic defaultValue, required int validContexts, required double ordinal, String help = "", bool allowMultiple = false})

Properties

allowMultiple → bool
final
argumentHelp → String
no setteroverride
argumentHelpShort → String
no setter
argumentString → String
no setterinherited
choices → List<AFConfigEntryDescription>
final
codeIdentifier → String
no setterinherited
defaultValue → dynamic
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
help → String
finalinherited
libraryId → AFLibraryID
finalinherited
name → String
finalinherited
ordinal → double
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validContexts → int
finalinherited

Methods

addArguments(ArgParser argParser) → void
override
addChoice({required String textValue, required String help, dynamic runtimeValue}) → void
addChoiceSection(String title) → void
addWildcard(String help) → void
allowedIn(int validContext) → bool
inherited
codeValue(AFConfig config) → String?
inherited
comment() → String
inherited
findChoice(String val) → AFConfigEntryDescription?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(AFConfig dest, dynamic value) → void
inherited
setValueWithString(AFConfig dest, String value) → void
inherited
toString() → String
A string representation of this object.
inherited
validate(dynamic value) → String?
Return an error message if the value is invalid, otherwise return null.
override
validateWithException(String value) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

wildcardValue → const String