deviceFormFactor property
AFFormFactor
get
deviceFormFactor
An appoximate form factor for the device.
Since web browsers can be resized arbitrarily, in the web case this returns the best approximation in AFFormFactor.
Implementation
AFFormFactor get deviceFormFactor {
return fundamentals.deviceFormFactor;
}