AFFundamentalThemeValue class
A value which can be exposed to and edited by the theme
Constructors
- AFFundamentalThemeValue({required AFThemeID id, required dynamic value})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited