AFUILibraryFundamentalThemeAreaBuilder class
- Implementers
Constructors
-
AFUILibraryFundamentalThemeAreaBuilder(Map<
AFThemeID, List> optionsForType)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
optionsForType
↔ Map<
AFThemeID, List> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedLocalesApp
→ List<
Locale> -
final
-
translationSet
→ Map<
Locale, AFTranslationSet> -
final
-
values
→ Map<
AFThemeID, AFFundamentalThemeValue> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setOptionsForType(
AFThemeID id, List values) → void - Used to specify a list of string values that can be selected in the test drawer/theme panel for a given AFThemeID.
-
setTranslations(
Locale locale, Map< dynamic, String> translations) → void -
setValue(
AFThemeID id, dynamic value, {AFCreateDynamicDelegate? defaultCalculation, bool notNull = true}) → void - Set a fundamental value.
-
setValues(
Map< AFThemeID, dynamic> toSet) → void - Use to set multiple values, usually from a statically declared map.
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited