AFThemeAreaUtilties mixin
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
background(
AFThemeID? id, Brightness brightness) → Color -
color(
dynamic id) → Color? -
colors(
AFThemeID id) → AFColorPairing -
flag(
AFThemeID id) → int -
foreground(
AFThemeID? id, Brightness brightness) → Color -
icon(
dynamic idOrIcon, {dynamic iconColor, dynamic iconSize}) → Widget? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
size(
dynamic id, {double scale = 1.0}) → double? -
textStyle(
dynamic idOrTextStyle) → TextStyle? -
toString(
) → String -
A string representation of this object.
inherited
-
translate(
{AFWidgetID? wid, Object? text, required Locale locale}) → String? -
translation(
{Object? text, required Locale locale}) → String? -
value(
AFThemeID? id) → dynamic -
weight(
dynamic id) → FontWeight?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
colorDarker(
Color c, int percent) → Color -
colorLighter(
Color c, int percent) → Color